% uses prediction from x,y,z to w and approximates xlate, ylate, zlate

fs=96000;
brirlen=15000;
maxDiffuseStart=0.1; % seconds
rnum           =  1; % number of reflections

bfrir=wavread('soundfieldELA2RIR96');
%load rirs_BC_329_all sf_y25_mx5_lx2
%bfrir=sf_y25_mx5_lx2;

if exist('bfrotate','var')
    bfrotateRad=bfrotate/180*pi;
    bfrir(:,2:3)=[bfrir(:,2)*cos(bfrotateRad)-bfrir(:,3)*sin(bfrotateRad),bfrir(:,2)*sin(bfrotateRad)+bfrir(:,3)*cos(bfrotateRad)];
end

if exist('azioffs','var')==0
    azioffs=0;
end
if exist('eleoffs','var')==0
    eleoffs=0;
end

% setup data for measured KEMAR hrtfs
if exist('D','var')==0
    cd KEMAR_EPFL/
    D=setupHRTFs(44100);
    cd ..
end

% separate direct sound from the rest
wenv=smooth(abs(bfrir(1:brirlen,1)),50);
[trash,dsidx]=max(wenv);
maxlen=fs/100;
dslen=maxlen;
while dslen==maxlen
    [trash,dslen]=min(wenv(dsidx:dsidx+maxlen));
    maxlen=maxlen-1;
end

zidx=dsidx+dslen;

n=1;
bf=bfrir(1:zidx,:);
[a,e]=bfdir(bf);
refl{n,1}=1;
refl{n,2}=bf(:,1); % w
refl{n,3}=a;
refl{n,4}=e;

ebrir=zeros(brirlen,2);
ewrir=zeros(brirlen,1);

% create early BRIR
for n=1:rnum
    % ewrir
    range=refl{n,1}:refl{n,1}+length(refl{n,2})-1;
    ewrir(range,1)=ewrir(range,1)+refl{n,2};
    % ebrir
    refl{n,3}+azioffs
    refl{n,4}+eleoffs
    h=resample(hrtf(refl{n,3}+azioffs,refl{n,4}+eleoffs,D),960,441);
%    h=resample(hrtf(0,0,D),960,441);
    l=conv(h(:,1),refl{n,2});
    r=conv(h(:,2),refl{n,2});
    range=refl{n,1}:refl{n,1}+length(l)-1;
    ebrir(range,1)=ebrir(range,1)+l;
    range=refl{n,1}:refl{n,1}+length(r)-1;
    ebrir(range,2)=ebrir(range,2)+r;
end

% calculate estimate of diffuse B-Format RIR
dbfrir=bfrir;
dbfrir(1:zidx,:)=0;

ebrir441=resample(ebrir,44100,96000);

wavwrite(dbfrir,96000,32,'__soundfieldRIR96_diffuse');

% run Christof's script here
generate_late_BRIR_phi_abs
lbrir=wavread('late_brir');

% get levels right
bfrir441=resample(bfrir,441,960);
% estimate correct energies from bformat rir
sl=bfrir(:,1)+0.7/sqrt(2)*(bfrir(:,2)*0.5+bfrir(:,3)*sqrt(3)/2);
sr=bfrir(:,1)+0.7/sqrt(2)*(bfrir(:,2)*0.5-bfrir(:,3)*sqrt(3)/2);
ebfe=sum(sl(1:zidx(1),1).^2)+sum(sr(1:zidx(1),1).^2);
ebfl=sum(sl(zidx(1):1:end,1).^2)+sum(sr(zidx(1):1:end,1).^2);
% calculate energy from generated early and late brirs
ege=sum(sum(ebrir441.^2));
egl=sum(sum(lbrir.^2));

disp(['early/late energy ratio (from B-Format RIR): ' num2str(ebfe/ebfl)]);

brir=lbrir;
brir(1:length(ebrir441),:)=brir(1:length(ebrir441),:)+ebrir441*sqrt(ebfe/ebfl*egl/ege);

% remove silence before direct sound
renv=smooth(abs(refl{1,2}));
start=find(renv>0.0005*max(renv),1);
refl{1,2}=refl{1,2}(start:end);
for i=2:rnum
    refl{i,1}=refl{i,1}-start+1;
end

% do spectrum matching using the direct sound of the soundfield RIR
dw=bfrir441(:,1);
dw(round(zidx(1)*44.1/96):end)=0;
DW=abs(fft(dw));
DWthr=0.8*mean(DW);
i=1;
% compensate drop at low freq
while DW(i)<DWthr
    DW(i)=DWthr;
    i=i+1;
end
i=length(DW);
while DW(i)<DWthr
    DW(i)=DWthr;
    i=i-1;
end

BRIRSPM=fft(brir(1:length(dw),:))./[DW,DW];
brirspm=ifft(BRIRSPM);