% generate late BRIR from B-Format RIR and HRTFs

%close all
%clear all

readHRTFs2;

fs = 44100; % sampling rate of HRTFs
sm = 2000;


% read B-format rir, resample, and cut early part
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[bf_rir fs_rir nbits] = wavread('__soundfieldRIR96_diffuse.wav');

bf_rir = resample(bf_rir, fs, fs_rir);

%offset = round(fs*0.05);
%bf_rir = bf_rir(offset:end,:);

% N = round(fs*0.5);
% figure
% plot(bf_rir(1:N,:));


% compute late BRIR
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

N = length(h);
NHRTF = length(h{1});
NRIR  = length(bf_rir);

% pad bf_rir to be power of two length

NRIR = 2^round(log2(NRIR)+0.49999);
bf_rir(NRIR,1) = 0;
specsize = NRIR/2 + 1;

% convert HRTFs to frequency domain

H=cell(1,N);
for i = 1:N,
    disp([i,N]);
  tmp = fft([h{i}; zeros(NRIR-NHRTF,2)]);
  H{i} = tmp(1:specsize,:);
end

% convert RIR to the frequency domain

BF_RIR = fft(bf_rir);
BF_RIR = BF_RIR(1:specsize,:);
PW = real(BF_RIR(:,1).*conj(BF_RIR(:,1)));
PW = smooth(PW, sm);

% compute diffuse sound power spectrum at ear entrances

PL = zeros(specsize,1);
PR = zeros(specsize,1);
for i = 1:N,
  PL = PL + real(1/N*H{i}(:,1).*conj(H{i}(:,1)));
  PR = PR + real(1/N*H{i}(:,2).*conj(H{i}(:,2)));
end
PL = PL.*PW;
PR = PR.*PW;

% compute cross-correlation coefficient

num  = zeros(specsize,1);
den1 = zeros(specsize,1);
den2 = zeros(specsize,1);
for i = 1:N,
  num  = num + (H{i}(:,1).*conj(H{i}(:,2)));
  den1 = den1 + abs(H{i}(:,1).*conj(H{i}(:,1)));
  den2 = den2 + abs(H{i}(:,2).*conj(H{i}(:,2)));
end
Phi = abs(num) ./ sqrt(den1.*den2);

% plot results

freqs = (0:(specsize-1))/(specsize-1)*fs/2;

figure
subplot(3,1,1)
plot(bf_rir(:,1))
axis tight
xlabel('time index')
ylabel('W')
subplot(3,1,2)
plot(freqs, PL)
hold on
plot(freqs, PR, 'r')
hold off
xlabel('frequency [kHz]')
ylabel('diffuse power')
legend('left', 'right')
axis tight
grid
subplot(3,1,3)
plot(freqs, Phi)
axis tight
xlabel('frequency [kHz]')
ylabel('\Phi')
grid

% compute b-format decoding parameter

A = 3.*Phi-1;
B = -2.*(Phi+1);
C = Phi+1;

v = (-B-sqrt(B.^2-4*A.*C))./(2.*A);

% compute filter H

W = BF_RIR(:,1);
Y = BF_RIR(:,3)./sqrt(2);
w = 1-v;

PL2 = smooth(abs(v.*W + w.*Y).^2, sm);
PR2 = smooth(abs(v.*W - w.*Y).^2, sm);

HL = sqrt(PL ./ PL2);
HR = sqrt(PR ./ PR2);

% compute output BRIR

BRIR_L = HL.*(v.*W + w.*Y);
BRIR_R = HR.*(v.*W - w.*Y);

brir_l = real(ifft([BRIR_L; flipud(conj(BRIR_L(2:(specsize-1))))]));
brir_r = real(ifft([BRIR_R; flipud(conj(BRIR_R(2:(specsize-1))))]));
brir_l = brir_l(1:(end-1000));
brir_r = brir_r(1:(end-1000));

wavwrite([brir_l brir_r], fs, nbits, 'late_brir.wav');

% plot results

figure
subplot(3,1,1)
plot(freqs, HL)
hold on
plot(freqs, HR, 'r')
hold off
xlabel('frequency [kHz]')
ylabel('H')
legend('left', 'right')
axis tight
grid
subplot(3,1,2)
plot(freqs, v)
axis tight
xlabel('frequency [kHz]')
ylabel('v')
grid
subplot(3,1,3)
plot(brir_l)
axis tight
xlabel('time index')
ylabel('brir_l')
grid


