% ============================================================
% make figures and test equations
% ============================================================

% =============================================

% plot left and right pointing responses for
% various v

vv = [0.2 0.4 0.6 0.8];
Nv = length(vv);

colrs{1} = 'k-';
colrs{2} = 'k--';
colrs{3} = 'k-';
colrs{4} = 'k--';
colrs{5} = 'k';
colrs{6} = 'k';
colrs{7} = 'k';
colrs{8} = 'k';
widths = [2 2 1 1 1 1 1 1];

angledeg = 0:360;
angle = angledeg * pi / 180;

figure(3)
g = subplot(2,1,1);
% plot left pointing respones
legendstr = {};
for i = 1:Nv,
  w = 1-vv(i);
  rsp = vv(i)-w*cos(angle);
  x = cos(angle).*abs(rsp);
  y = sin(angle).*abs(rsp);
  plot(x,y,colrs{i},'linewidth',widths(i));
  hold on
  legendstr{i} = ['v = ' num2str(vv(i))];
end
hold off

axis([-1.1 1.1 -1.1 1.1])
hold on
x = cos(angle);
y = sin(angle);
plot(x,y,'k:','linewidth',0.80);
plot(.75.*x,.75.*y,'k:','linewidth',0.80);
plot(.5.*x,.5.*y,'k:','linewidth',0.80);
plot(.25.*x,.25.*y,'k:','linewidth',0.80);
plot([0 0],[-2 2],'k:','linewidth',0.80);
plot([-2 2],[0 0],'k:','linewidth',0.80);
plot([1 1],[-2 2],'k:','linewidth',0.80);
plot([-1 -1],[-2 2],'k:','linewidth',0.80);
plot([-2 2],[1 1],'k:','linewidth',0.80);
plot([-2 2],[-1 -1],'k:','linewidth',0.80);
hold off
axis square
set(g,'XTickLabel',[])
set(g,'YTickLabel',[])
legend(legendstr, 'Location', 'NorthEastOutside')
title('D_L');


g = subplot(2,1,2);
% plot right pointing respones
legendstr = {};
for i = 1:Nv,
  w = 1-vv(i);
  rsp = vv(i)+w*cos(angle);
  x = cos(angle).*abs(rsp);
  y = sin(angle).*abs(rsp);
  plot(x,y,colrs{i},'linewidth',widths(i));
  hold on
  legendstr{i} = ['v = ' num2str(vv(i))];
end
hold off

axis([-1.1 1.1 -1.1 1.1])
hold on
x = cos(angle);
y = sin(angle);
plot(x,y,'k:','linewidth',0.80);
plot(.75.*x,.75.*y,'k:','linewidth',0.80);
plot(.5.*x,.5.*y,'k:','linewidth',0.80);
plot(.25.*x,.25.*y,'k:','linewidth',0.80);
plot([0 0],[-2 2],'k:','linewidth',0.80);
plot([-2 2],[0 0],'k:','linewidth',0.80);
plot([1 1],[-2 2],'k:','linewidth',0.80);
plot([-1 -1],[-2 2],'k:','linewidth',0.80);
plot([-2 2],[1 1],'k:','linewidth',0.80);
plot([-2 2],[-1 -1],'k:','linewidth',0.80);
hold off
axis square
set(g,'XTickLabel',[])
set(g,'YTickLabel',[])
legend(legendstr, 'Location', 'NorthEastOutside')
title('D_R');

if savefigs == 1
  print -depsc '../figureseps/dldr.eps'
end


% =============================================

% plot normalized cross-correlation coefficient
% as a function of v

% v = 0:0.01:1;
% phi = (v.^2+2.*v-1)./(3.*v.^2-2.*v+1);
% figure
% subplot(2,2,1)
% plot(v,phi,'k','linewidth',2)
% axis([0 1 -1.2 1.2])
% grid
% xlabel('v')
% ylabel('\Phi')
% 
% if savefigs == 1
%   print -depsc '../figureseps/vversusphi.eps'
% end


% =============================================

% plot v as a function of the normalized cross-
% correlation coefficient

phi = -1:0.01:1;
A = 3.*phi-1;
B = -2.*(phi+1);
C = phi+1;
v1 = (-B+sqrt(B.^2-4*A.*C))./(2.*A);
v2 = (-B-sqrt(B.^2-4*A.*C))./(2.*A);

figure(4)
subplot(2,2,1)
% plot(phi,v1,'k--','linewidth',2)
% hold on
plot(phi,v2,'k','linewidth',2)
% hold off
axis([-1 1 -0.1 1.1])
grid
xlabel('\Phi')
ylabel('v')

if savefigs == 1
  print -depsc '../figureseps/phiversusv.eps'
end


% =============================================
